---
template: mainpanel
source_form: markdown
name: Trello Cardlist Pinned
updated: October 2016
title: Trello Cardlist Pinned
---
### Pinned

* Things to feed into Pyxie
* Licensing links
* .p files are parsing tests. If they compile, they should be renamed .pyxie which are compilation tests.
* How to deploy the website
* Release tasks
